==> ?f=plg_jw_uberPageBreak-v1.0_j1.5.zip: UberPageBreak/tmpl/Tabs/default.php <==
<?php 
/*
// JoomlaWorks "UberPageBreak" Plugin for Joomla! 1.5.x - Version 1.0
// Copyright (c) 2006 - 2010 JoomlaWorks, a business unit of Nuevvo Webware Ltd. All rights reserved.
// Released under the GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
// More info at http://www.joomlaworks.gr
// Designed and developed by the JoomlaWorks team
// ***Last update: June 25th, 2010***
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

?>

<?php if($ubpTOC): ?>
<div id="pageBreakTOC">
	<div id="pageBreakTOCHeader">
		<?php echo JText::_('Table of contents'); ?>
	</div>

	<span id="pageBreakNavigationPrevNext">
		<?php if($output->navPrevLink): ?>
		<a href="<?php echo $output->navPrevLink; ?>"><span class="navPrev">&laquo; <?php echo JText::_('Prev'); ?></span></a>
		<?php else: ?>
		<span class="navPrev">&laquo; <?php echo JText::_('Prev'); ?></span>
		<?php endif; ?>

		<?php if($ubpAllPagesLink): ?>
		<span id="pageBreakTOCFooter<?php if($output->footerActiveClass): ?> active<?php endif; ?>">
			<a class="pageBreakTOCFooterLink" href="<?php echo $output->footerLink; ?>"><?php echo JText::_('All Pages'); ?></a>
		</span>
		<?php endif; ?>

		<?php if($output->navNextLink): ?>
		<a href="<?php echo $output->navNextLink; ?>"><span class="navNext"><?php echo JText::_('Next'); ?> &raquo;</span></a>
		<?php else: ?>
		<span class="navNext"><?php echo JText::_('Next'); ?> &raquo;</span>
		<?php endif; ?>	
	</span>
	
	<ul>
		<li class="even<?php if($output->headerActiveClass): ?> active<?php endif; ?>"><a href="<?php echo $output->headerLink; ?>"><?php echo $output->headerTitle; ?></a></li>
		<?php foreach($output->links as $key=>$link): ?>
		<li class="<?php echo $link->linkOddOrEvenClass; ?><?php if($link->linkActiveClass): ?> active<?php endif; ?>"><a href="<?php echo $link->pagelink; ?>"><?php echo $link->title; ?></a></li>
		<?php endforeach; ?>
	</ul>
	<div class="clr"></div>
</div>
<?php endif; ?>

<!-- Text starts here -->
<?php echo $output->pageText; ?>
<!-- Text ends here -->

<?php if(!($showall && $showLinkToAll) && ($ubpNavigation || $ubpPageCounter)): ?>
<div id="pageBreakNavigation">
	<?php if($ubpNavigation): ?>
	<?php echo $output->navPageLinks; ?>
	<?php endif; ?>
	
	<?php if($ubpPageCounter): ?>
	<div class="pageBreakCounter">
		(<?php echo $output->pageCounter; ?>)
	</div>
	<?php endif; ?>
</div>
<?php endif; ?>

==> ?f=plg_jw_uberPageBreak-v1.1_j1.5.zip: UberPageBreak/tmpl/Tabs/default.php <==
<?php 
/**
 * @version		1.1
 * @package		UberPageBreak (plugin)
 * @author    JoomlaWorks - http://www.joomlaworks.gr
 * @copyright	Copyright (c) 2006 - 2011 JoomlaWorks, a business unit of Nuevvo Webware Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

?>

<?php if($ubpTOC): ?>
<div id="pageBreakTOC">
	<div id="pageBreakTOCHeader">
		<?php echo JText::_('Table of contents'); ?>
	</div>

	<span id="pageBreakNavigationPrevNext">
		<?php if($output->navPrevLink): ?>
		<a href="<?php echo $output->navPrevLink; ?>"><span class="navPrev">&laquo; <?php echo JText::_('Prev'); ?></span></a>
		<?php else: ?>
		<span class="navPrev">&laquo; <?php echo JText::_('Prev'); ?></span>
		<?php endif; ?>

		<?php if($ubpAllPagesLink): ?>
		<span id="pageBreakTOCFooter<?php if($output->footerActiveClass): ?> active<?php endif; ?>">
			<a class="pageBreakTOCFooterLink" href="<?php echo $output->footerLink; ?>"><?php echo JText::_('All Pages'); ?></a>
		</span>
		<?php endif; ?>

		<?php if($output->navNextLink): ?>
		<a href="<?php echo $output->navNextLink; ?>"><span class="navNext"><?php echo JText::_('Next'); ?> &raquo;</span></a>
		<?php else: ?>
		<span class="navNext"><?php echo JText::_('Next'); ?> &raquo;</span>
		<?php endif; ?>	
	</span>
	
	<ul>
		<li class="even<?php if($output->headerActiveClass): ?> active<?php endif; ?>"><a href="<?php echo $output->headerLink; ?>"><?php echo $output->headerTitle; ?></a></li>
		<?php foreach($output->links as $key=>$link): ?>
		<li class="<?php echo $link->linkOddOrEvenClass; ?><?php if($link->linkActiveClass): ?> active<?php endif; ?>"><a href="<?php echo $link->pagelink; ?>"><?php echo $link->title; ?></a></li>
		<?php endforeach; ?>
	</ul>
	<div class="clr"></div>
</div>
<?php endif; ?>

<!-- Text starts here -->
<?php echo $output->pageText; ?>
<!-- Text ends here -->

<?php if(!($showall && $showLinkToAll) && ($ubpNavigation || $ubpPageCounter)): ?>
<div id="pageBreakNavigation">
	<?php if($ubpNavigation): ?>
	<?php echo $output->navPageLinks; ?>
	<?php endif; ?>
	
	<?php if($ubpPageCounter): ?>
	<div class="pageBreakCounter">
		(<?php echo $output->pageCounter; ?>)
	</div>
	<?php endif; ?>
</div>
<?php endif; ?>
